<?php

namespace Litecms\Simplepackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Simplepackage\Models\Simplepackage;

class SimplepackagePolicy
{

    /**
     * Determine if the given user can view the simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function view(UserPolicy $user, Simplepackage $simplepackage)
    {
        if ($user->canDo('simplepackage.simplepackage.view') && $user->isAdmin()) {
            return true;
        }

        return $simplepackage->user_id == user_id() && $simplepackage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('simplepackage.simplepackage.create');
    }

    /**
     * Determine if the given user can update the given simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function update(UserPolicy $user, Simplepackage $simplepackage)
    {
        if ($user->canDo('simplepackage.simplepackage.edit') && $user->isAdmin()) {
            return true;
        }

        return $simplepackage->user_id == user_id() && $simplepackage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Simplepackage $simplepackage)
    {
        return $simplepackage->user_id == user_id() && $simplepackage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Simplepackage $simplepackage)
    {
        if ($user->canDo('simplepackage.simplepackage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given simplepackage.
     *
     * @param UserPolicy $user
     * @param Simplepackage $simplepackage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Simplepackage $simplepackage)
    {
        if ($user->canDo('simplepackage.simplepackage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
